@@ -8,7 +8,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
-from .callService import callService, callGetService, callPostService, callPutService, callDeleteService, callServiceSendMultiPartFiles
+from .callService import callService, callGetService, callPostService, callPutService, callDeleteService, callServiceSendMultiPartFiles, callServiceSendMultiPartFilesAndData
 from .pythonObjCompare import objectsEqual
 
 from ._version import get_versions
